@@ -36,8 +36,10 @@ class DeckenGUI:
 			self.set_tables_created('magic')
 			self.plugin.load_sets(self.get_conexao())
 			
-		self.cartas = self.plugin.all_cards(self.get_conexao())
-
+		self.filtros = {}
+		self.checkbox_teste()
+			
+		self.cartas = self.plugin.all_cards(self.get_conexao(), self.filtros)
 		
 		self.imagem = self.get_widget('imagem_carta')
 		pixbuf = gtk.gdk.pixbuf_new_from_file(self.plugin.get_image_back())
@@ -75,6 +77,43 @@ class DeckenGUI:
 		#self.wTree.signal_autoconnect(dic)
 		self.builder.connect_signals(self)
 		
+	def na_tabela(self, tabela):
+		for indice, select_filter in enumerate(self.plugin.select_filters):
+			label = gtk.Label(select_filter)
+			combobox = gtk.combo_box_new_text()
+			self.filtros[select_filter] = combobox
+			for i in self.plugin.get_select_filter_values(select_filter):
+				combobox.append_text(i)
+			box = gtk.HBox(True, 0)
+			box.pack_start(label, True, True, 0)
+			box.pack_start(combobox, True, True, 0)
+			tabela.attach(box, 0, 1, indice, indice + 1)
+			label.show()
+			combobox.show()
+			box.show()
+		palavras_tipos = ['Creature', 'Artifact', 'Planeswalker', 'Enchantment',
+		 	'Sorcery', 'Instant', 'Land']		
+		
+	def checkbox_teste(self):
+		scrolledFilters = self.get_widget('scrolled_filters')
+		tabela = gtk.Table(len(self.plugin.select_filters) + 1, 1, True)
+		scrolledFilters.add_with_viewport(tabela)
+		# criaturas    feitiços
+		# artefatos    instantâneas
+		# planinautas  encantamentos
+		# terrenos
+		self.na_tabela(tabela)
+		refresh_button = gtk.Button('Refresh', gtk.STOCK_REFRESH)
+		refresh_button.connect('clicked', self.refresh)
+		tabela.attach(refresh_button, 0, 1, len(self.plugin.select_filters) , len(self.plugin.select_filters) + 1)
+		refresh_button.show()
+		tabela.show()
+	
+	def refresh(self, widget, data=None):
+		caixa_texto = self.get_widget('caixa_pesquisa')
+		self.filtrar_por_nome(caixa_texto)
+	
+		
 	def playlist_select_row(self, treeview, path, column):
    		self.cardlist_selected = self.liststore.get_iter(path)
 		column_values = []
@@ -111,12 +150,12 @@ class DeckenGUI:
 		if len(card) > 0:
 			print card
 			self.liststore.clear()
-			cards = self.plugin.find_by_name(self.get_conexao(), card)
+			cards = self.plugin.find_by_name(self.get_conexao(), card, self.filtros)
 			for i in cards:
 				self.liststore.append( self.plugin.value_columns_by_card(i) )
 		else:
 			self.liststore.clear()
-			lista = self.plugin.all_cards(self.get_conexao())
+			lista = self.plugin.all_cards(self.get_conexao(), self.filtros)
 			for i in lista:
 				self.liststore.append( self.plugin.value_columns_by_card(i) )
 		
